==> lkstlogtools-1.0.1.tar.gz: lkstlogtools-1.0.1/src/lksteh_sysinfo.c <==
/*
 lksteh_sysinfo -- record system & fs information handler
  
 Copyright (C) HITACHI,LTD. 2005
 WRITTEN BY HITACHI SYSTEMS DEVELOPMENT LABORATORY,
 Created by M.Hiramatsu <hiramatu@sdl.hitachi.co.jp>
  
 The development of this program is partly supported by IPA
 (Information-Technology Promotion Agency, Japan).
  
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

#include <linux/version.h>
#include <linux/module.h>
#include <linux/init.h>
#include <linux/lkst_private.h>
#include <linux/kernel.h>
#include <linux/hardirq.h>
#include "../include/extra_etypes.h"

MODULE_AUTHOR("M.Hiramatsu <hiramatu@sdl.hitachi.co.jp>");
MODULE_DESCRIPTION("system and fs information recording handler");
MODULE_LICENSE("GPL");

/* Declaration of hook header */
LKST_ETYPE_DEF_MODULE(EID_SYSTEM_INFO, INLINE, SYSTEM_INFO, "system information", \
		      "totalram/freeram", \
		      "sharedram/bufferram",\
		      "nr_files/nr_free_files", \
		      "nr_inodes/nr_unused_inodes");

#include <linux/mm.h>
extern struct inodes_stat_t inodes_stat;

static void lkst_evhandler_sysinfo(void *phookrec, int event_type,
				  lkst_arg_t arg1, lkst_arg_t arg2,
				  lkst_arg_t arg3, lkst_arg_t arg4)
{
	struct sysinfo i;
	preempt_disable();	/*IMPORTANT*/
	lkst_evhandlerprim_entry_log(event_type, arg1, arg2, arg3, arg4);
	if (!in_interrupt()){
		si_meminfo(&i);
		lkst_evhandlerprim_entry_log(LKST_ETYPE_SYSTEM_INFO,
					     LKST_ARG32(i.totalram,i.freeram), 
					     LKST_ARG32(i.sharedram,i.bufferram),
					     LKST_ARG32(files_stat.nr_files, 
							files_stat.nr_free_files),
					     LKST_ARG32(inodes_stat.nr_inodes,
							inodes_stat.nr_unused));
	}
	preempt_enable_no_resched();	/*VERY IMPORTANT*/
}


static int mod_init(void);
static void mod_cleanup(void);
module_init(mod_init);		/*define as initializer*/
module_exit(mod_cleanup);	/*define as terminator*/

static LKST_EH_DEV_DEF(sysinfo,
		       lkst_evhandler_sysinfo,
		       NULL,NULL,NULL);

static int mod_init(void)
{
	int	retval;
	/* Initialization of hook header */
	retval = lkst_hook_etype_register(&LKST_ETYPE_INFO(SYSTEM_INFO));
	if (retval < 0) {
		printk("lksteh_sysinfo: Error: failed to etype register (%d)\n", 
		       retval);
		goto init_err;
	}
	/* register an event handler */
	retval = lkst_eh_device_register(&LKST_EH_DEV(sysinfo));
	if (retval < 0) {
		printk("lksteh_sysinfo: Error: failed to evhandler register (%d)\n", 
		       retval);
		goto init_err;
	}
	return 0;
	
	init_err:
	mod_cleanup(); /*If occurs an error, invokes terminator.*/
	return retval;
}


static void mod_cleanup(void)
{
	if (LKST_EH_DEV(sysinfo).id != LKST_EVHANDLER_ID_VOID) {
		lkst_eh_device_unregister(&LKST_EH_DEV(sysinfo));
	}
	lkst_hook_etype_unregister(&LKST_ETYPE_INFO(SYSTEM_INFO));
}

==> lkstlogtools-1.1.0.tar.gz: lkstlogtools-1.1.0/src/lksteh_sysinfo.c <==
/*
 lksteh_sysinfo -- record system & fs information handler
  
 Copyright (C) HITACHI,LTD. 2005
 WRITTEN BY HITACHI SYSTEMS DEVELOPMENT LABORATORY,
 Created by M.Hiramatsu <hiramatu@sdl.hitachi.co.jp>
  
 The development of this program is partly supported by IPA
 (Information-Technology Promotion Agency, Japan).
  
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

#include <linux/version.h>
#include <linux/module.h>
#include <linux/init.h>
#include <linux/lkst_private.h>
#include <linux/kernel.h>
#include <linux/hardirq.h>
#include "../include/extra_etypes.h"

MODULE_AUTHOR("M.Hiramatsu <hiramatu@sdl.hitachi.co.jp>");
MODULE_DESCRIPTION("system and fs information recording handler");
MODULE_LICENSE("GPL");

/* Declaration of hook header */
LKST_ETYPE_DEF_MODULE(EID_SYSTEM_INFO, INLINE, SYSTEM_INFO,
		      "system information",
		      "totalram",
		      "freeram",
		      "sharedram",
		      "bufferram");

LKST_ETYPE_DEF_MODULE(EID_SYSTEM_INFO2, INLINE, SYSTEM_INFO2,
		      "system information 2",
		      "nr_files",
		      "nr_free_files",
		      "nr_inodes",
		      "nr_unused_inodes");

#include <linux/mm.h>
extern struct inodes_stat_t inodes_stat;

static void lkst_evhandler_sysinfo(void *phookrec, int event_type,
				  lkst_arg_t arg1, lkst_arg_t arg2,
				  lkst_arg_t arg3, lkst_arg_t arg4)
{
	struct sysinfo i;
	preempt_disable();	/*IMPORTANT*/
	lkst_evhandlerprim_entry_log(event_type, arg1, arg2, arg3, arg4);
	if (!in_interrupt()){
		si_meminfo(&i);
		lkst_evhandlerprim_entry_log(LKST_ETYPE_SYSTEM_INFO,
					     LKST_ARG(i.totalram),
					     LKST_ARG(i.freeram),
					     LKST_ARG(i.sharedram),
					     LKST_ARG(i.bufferram));
		lkst_evhandlerprim_entry_log(LKST_ETYPE_SYSTEM_INFO2,
				     LKST_ARG(files_stat.nr_files),
				     LKST_ARG(files_stat.nr_free_files),
				     LKST_ARG(inodes_stat.nr_inodes),
				     LKST_ARG(inodes_stat.nr_unused));
	}
	preempt_enable_no_resched();	/*VERY IMPORTANT*/
}


static int mod_init(void);
static void mod_cleanup(void);
module_init(mod_init);		/*define as initializer*/
module_exit(mod_cleanup);	/*define as terminator*/

static LKST_EH_DEV_DEF(sysinfo,
		       lkst_evhandler_sysinfo,
		       NULL,NULL,NULL);

static int mod_init(void)
{
	int	retval;
	/* Initialization of hook header */
	retval = lkst_hook_etype_register(&LKST_ETYPE_INFO(SYSTEM_INFO));
	if (retval < 0) {
		printk("lksteh_sysinfo: Error: "
		       "failed to register etype (%d)\n", retval);
		goto init_err;
	}
	retval = lkst_hook_etype_register(&LKST_ETYPE_INFO(SYSTEM_INFO2));
	if (retval < 0) {
		printk("lksteh_sysinfo: Error: "
		       "failed to register etype (%d)\n", retval);
		goto init_err;
	}

	/* register an event handler */
	retval = lkst_eh_device_register(&LKST_EH_DEV(sysinfo));
	if (retval < 0) {
		printk("lksteh_sysinfo: Error: "
		       "failed to register evhandler (%d)\n", retval);
		goto init_err;
	}
	return 0;
	
	init_err:
	mod_cleanup(); /*If occurs an error, invokes terminator.*/
	return retval;
}


static void mod_cleanup(void)
{
	if (LKST_EH_DEV(sysinfo).id != LKST_EVHANDLER_ID_VOID) {
		lkst_eh_device_unregister(&LKST_EH_DEV(sysinfo));
	}
	lkst_hook_etype_unregister(&LKST_ETYPE_INFO(SYSTEM_INFO));
	lkst_hook_etype_unregister(&LKST_ETYPE_INFO(SYSTEM_INFO2));
}
